# NAME

WWW::OpenAPIClient::Role - a Moose role for the spoonacular API

The spoonacular Nutrition, Recipe, and Food API allows you to access over thousands of recipes, thousands of ingredients, 800,000 food products, over 100,000 menu items, and restaurants. Our food ontology and semantic recipe search engine makes it possible to search for recipes using natural language queries, such as \"gluten free brownies without sugar\" or \"low fat vegan cupcakes.\" You can automatically calculate the nutritional information for any recipe, analyze recipe costs, visualize ingredient lists, find recipes for what's in your fridge, find recipes based on special diets, nutritional requirements, or favorite ingredients, classify recipes into types and cuisines, convert ingredient amounts, or even compute an entire meal plan. With our powerful API, you can create many kinds of food and especially nutrition apps.

Special diets/dietary requirements currently available include: vegan, vegetarian, pescetarian, gluten free, grain free, dairy free, high protein, whole 30, low sodium, low carb, Paleo, ketogenic, FODMAP, and Primal.

# VERSION

Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.1
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PerlClientCodegen
For more information, please visit [https://spoonacular.com/contact](https://spoonacular.com/contact)

## A note on Moose

This role is the only component of the library that uses Moose. See
WWW::OpenAPIClient::ApiFactory for non-Moosey usage.

# SYNOPSIS

The Perl Generator in the OpenAPI Generator project builds a library of Perl modules to interact with
a web service defined by a OpenAPI Specification. See below for how to build the
library.

This module provides an interface to the generated library. All the classes,
objects, and methods (well, not quite \*all\*, see below) are flattened into this
role.

        package MyApp;
        use Moose;
        with 'WWW::OpenAPIClient::Role';

        package main;

        my $api = MyApp->new({ tokens => $tokens });

        my $pet = $api->get_pet_by_id(pet_id => $pet_id);


## Structure of the library

The library consists of a set of API classes, one for each endpoint. These APIs
implement the method calls available on each endpoint.

Additionally, there is a set of "object" classes, which represent the objects
returned by and sent to the methods on the endpoints.

An API factory class is provided, which builds instances of each endpoint API.

This Moose role flattens all the methods from the endpoint APIs onto the consuming
class. It also provides methods to retrieve the endpoint API objects, and the API
factory object, should you need it.

For documentation of all these methods, see AUTOMATIC DOCUMENTATION below.

## Configuring authentication

In the normal case, the OpenAPI Spec will describe what parameters are
required and where to put them. You just need to supply the tokens.

    my $tokens = {
        # basic
        username => $username,
        password => $password,

        # oauth
        access_token => $oauth_token,

        # keys
        $some_key => { token => $token,
                       prefix => $prefix,
                       in => $in,             # 'head||query',
                       },

        $another => { token => $token,
                      prefix => $prefix,
                      in => $in,              # 'head||query',
                      },
        ...,

        };

        my $api = MyApp->new({ tokens => $tokens });

Note these are all optional, as are `prefix` and `in`, and depend on the API
you are accessing. Usually `prefix` and `in` will be determined by the code generator from
the spec and you will not need to set them at run time. If not, `in` will
default to 'head' and `prefix` to the empty string.

The tokens will be placed in a L<WWW::OpenAPIClient::Configuration> instance
as follows, but you don't need to know about this.

- `$cfg->{username}`

    String. The username for basic auth.

- `$cfg->{password}`

    String. The password for basic auth.

- `$cfg->{api_key}`

    Hashref. Keyed on the name of each key (there can be multiple tokens).

            $cfg->{api_key} = {
                    secretKey => 'aaaabbbbccccdddd',
                    anotherKey => '1111222233334444',
                    };

- `$cfg->{api_key_prefix}`

    Hashref. Keyed on the name of each key (there can be multiple tokens). Note not
    all api keys require a prefix.

            $cfg->{api_key_prefix} = {
                    secretKey => 'string',
                    anotherKey => 'same or some other string',
                    };

- `$cfg->{access_token}`

    String. The OAuth access token.

# METHODS

## `base_url`

The generated code has the `base_url` already set as a default value. This method
returns the current value of `base_url`.

## `api_factory`

Returns an API factory object. You probably won't need to call this directly.

        $self->api_factory('Pet'); # returns a WWW::OpenAPIClient::PetApi instance

        $self->pet_api;            # the same

# MISSING METHODS

Most of the methods on the API are delegated to individual endpoint API objects
(e.g. Pet API, Store API, User API etc). Where different endpoint APIs use the
same method name (e.g. `new()`), these methods can't be delegated. So you need
to call `$api->pet_api->new()`.

In principle, every API is susceptible to the presence of a few, random, undelegatable
method names. In practice, because of the way method names are constructed, it's
unlikely in general that any methods will be undelegatable, except for:

        new()
        class_documentation()
        method_documentation()

To call these methods, you need to get a handle on the relevant object, either
by calling `$api->foo_api` or by retrieving an object, e.g.
`$api->get_pet_by_id(pet_id => $pet_id)`. They are class methods, so
you could also call them on class names.

# BUILDING YOUR LIBRARY

See the homepage `https://openapi-generator.tech` for full details.
But briefly, clone the git repository, build the codegen codebase, set up your build
config file, then run the API build script. You will need git, Java 7 or 8 and Apache
maven 3.0.3 or better already installed.

The config file should specify the project name for the generated library:

        {"moduleName":"WWW::MyProjectName"}

Your library files will be built under `WWW::MyProjectName`.

          $ git clone https://github.com/openapitools/openapi-generator
          $ cd openapi-generator
          $ mvn package
          $ java -jar modules/openapi-generator-cli/target/openapi-generator-cli.jar generate \
    -i [URL or file path to JSON OpenAPI API spec] \
    -g perl \
    -c /path/to/config/file.json \
    -o /path/to/output/folder

Bang, all done. Run the `autodoc` script in the `bin` directory to see the API
you just built.

# AUTOMATIC DOCUMENTATION

You can print out a summary of the generated API by running the included
`autodoc` script in the `bin` directory of your generated library. A few
output formats are supported:

          Usage: autodoc [OPTION]

    -w           wide format (default)
    -n           narrow format
    -p           POD format
    -H           HTML format
    -m           Markdown format
    -h           print this help message
    -c           your application class


The `-c` option allows you to load and inspect your own application. A dummy
namespace is used if you don't supply your own class.

# DOCUMENTATION FROM THE OpenAPI Spec

Additional documentation for each class and method may be provided by the OpenAPI
spec. If so, this is available via the `class_documentation()` and
`method_documentation()` methods on each generated object class, and the
`method_documentation()` method on the endpoint API classes:

        my $cmdoc = $api->pet_api->method_documentation->{$method_name};

        my $odoc = $api->get_pet_by_id->(pet_id => $pet_id)->class_documentation;
        my $omdoc = $api->get_pet_by_id->(pet_id => $pet_id)->method_documentation->{method_name};


Each of these calls returns a hashref with various useful pieces of information.

# Installation Prerequisites

Use [cpanm](https://metacpan.org/pod/distribution/App-cpanminus/bin/cpanm) to install the module dependencies:

```
cpanm --local-lib=~/perl5 local::lib && eval $(perl -I ~/perl5/lib/perl5/ -Mlocal::lib)
cpanm --quiet --no-interactive Class::Accessor Test::Exception Test::More Log::Any LWP::UserAgent URI::Query Module::Runtime DateTime Module::Find Moose::Role JSON
```

# LOAD THE MODULES

To load the API packages:
```perl
use WWW::OpenAPIClient::DefaultApi;
use WWW::OpenAPIClient::IngredientsApi;
use WWW::OpenAPIClient::MealPlanningApi;
use WWW::OpenAPIClient::MenuItemsApi;
use WWW::OpenAPIClient::MiscApi;
use WWW::OpenAPIClient::ProductsApi;
use WWW::OpenAPIClient::RecipesApi;
use WWW::OpenAPIClient::WineApi;

```

To load the models:
```perl
use WWW::OpenAPIClient::Object::AddMealPlanTemplate200Response;
use WWW::OpenAPIClient::Object::AddMealPlanTemplate200ResponseItemsInner;
use WWW::OpenAPIClient::Object::AddMealPlanTemplate200ResponseItemsInnerValue;
use WWW::OpenAPIClient::Object::AddToMealPlanRequest;
use WWW::OpenAPIClient::Object::AddToMealPlanRequest1;
use WWW::OpenAPIClient::Object::AddToMealPlanRequest1Value;
use WWW::OpenAPIClient::Object::AddToMealPlanRequest1ValueIngredientsInner;
use WWW::OpenAPIClient::Object::AddToShoppingListRequest;
use WWW::OpenAPIClient::Object::AnalyzeARecipeSearchQuery200Response;
use WWW::OpenAPIClient::Object::AnalyzeARecipeSearchQuery200ResponseDishesInner;
use WWW::OpenAPIClient::Object::AnalyzeARecipeSearchQuery200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200Response;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseParsedInstructionsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeRequest;
use WWW::OpenAPIClient::Object::AnalyzeRecipeRequest1;
use WWW::OpenAPIClient::Object::AutocompleteIngredientSearch200ResponseInner;
use WWW::OpenAPIClient::Object::AutocompleteMenuItemSearch200Response;
use WWW::OpenAPIClient::Object::AutocompleteProductSearch200Response;
use WWW::OpenAPIClient::Object::AutocompleteProductSearch200ResponseResultsInner;
use WWW::OpenAPIClient::Object::AutocompleteRecipeSearch200ResponseInner;
use WWW::OpenAPIClient::Object::ClassifyCuisine200Response;
use WWW::OpenAPIClient::Object::ClassifyGroceryProduct200Response;
use WWW::OpenAPIClient::Object::ClassifyGroceryProductBulk200ResponseInner;
use WWW::OpenAPIClient::Object::ClassifyGroceryProductBulkRequestInner;
use WWW::OpenAPIClient::Object::ClassifyGroceryProductRequest;
use WWW::OpenAPIClient::Object::ClearMealPlanDayRequest;
use WWW::OpenAPIClient::Object::ComputeGlycemicLoad200Response;
use WWW::OpenAPIClient::Object::ComputeGlycemicLoad200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::ComputeGlycemicLoadRequest;
use WWW::OpenAPIClient::Object::ComputeIngredientAmount200Response;
use WWW::OpenAPIClient::Object::ConnectUser200Response;
use WWW::OpenAPIClient::Object::ConnectUserRequest;
use WWW::OpenAPIClient::Object::ConvertAmounts200Response;
use WWW::OpenAPIClient::Object::CreateRecipeCard200Response;
use WWW::OpenAPIClient::Object::DeleteFromMealPlanRequest;
use WWW::OpenAPIClient::Object::DetectFoodInText200Response;
use WWW::OpenAPIClient::Object::DetectFoodInText200ResponseAnnotationsInner;
use WWW::OpenAPIClient::Object::GenerateMealPlan200Response;
use WWW::OpenAPIClient::Object::GenerateMealPlan200ResponseNutrients;
use WWW::OpenAPIClient::Object::GenerateShoppingList200Response;
use WWW::OpenAPIClient::Object::GenerateShoppingListRequest;
use WWW::OpenAPIClient::Object::GetARandomFoodJoke200Response;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200Response;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner;
use WWW::OpenAPIClient::Object::GetComparableProducts200Response;
use WWW::OpenAPIClient::Object::GetComparableProducts200ResponseComparableProducts;
use WWW::OpenAPIClient::Object::GetComparableProducts200ResponseComparableProductsProteinInner;
use WWW::OpenAPIClient::Object::GetConversationSuggests200Response;
use WWW::OpenAPIClient::Object::GetConversationSuggests200ResponseSuggests;
use WWW::OpenAPIClient::Object::GetConversationSuggests200ResponseSuggestsInner;
use WWW::OpenAPIClient::Object::GetDishPairingForWine200Response;
use WWW::OpenAPIClient::Object::GetIngredientInformation200Response;
use WWW::OpenAPIClient::Object::GetIngredientInformation200ResponseNutrition;
use WWW::OpenAPIClient::Object::GetIngredientSubstitutes200Response;
use WWW::OpenAPIClient::Object::GetMealPlanTemplate200Response;
use WWW::OpenAPIClient::Object::GetMealPlanTemplate200ResponseDaysInner;
use WWW::OpenAPIClient::Object::GetMealPlanTemplate200ResponseDaysInnerItemsInner;
use WWW::OpenAPIClient::Object::GetMealPlanTemplate200ResponseDaysInnerItemsInnerValue;
use WWW::OpenAPIClient::Object::GetMealPlanTemplates200Response;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200Response;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInner;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerItemsInner;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerItemsInnerValue;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerNutritionSummary;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner;
use WWW::OpenAPIClient::Object::GetMenuItemInformation200Response;
use WWW::OpenAPIClient::Object::GetProductInformation200Response;
use WWW::OpenAPIClient::Object::GetProductInformation200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::GetRandomFoodTrivia200Response;
use WWW::OpenAPIClient::Object::GetRandomRecipes200Response;
use WWW::OpenAPIClient::Object::GetRandomRecipes200ResponseRecipesInner;
use WWW::OpenAPIClient::Object::GetRecipeEquipmentByID200Response;
use WWW::OpenAPIClient::Object::GetRecipeEquipmentByID200ResponseEquipmentInner;
use WWW::OpenAPIClient::Object::GetRecipeInformation200Response;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseExtendedIngredientsInner;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseExtendedIngredientsInnerMeasures;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseWinePairing;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseWinePairingProductMatchesInner;
use WWW::OpenAPIClient::Object::GetRecipeInformationBulk200ResponseInner;
use WWW::OpenAPIClient::Object::GetRecipeIngredientsByID200Response;
use WWW::OpenAPIClient::Object::GetRecipeIngredientsByID200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::GetRecipeNutritionWidgetByID200Response;
use WWW::OpenAPIClient::Object::GetRecipeNutritionWidgetByID200ResponseBadInner;
use WWW::OpenAPIClient::Object::GetRecipeNutritionWidgetByID200ResponseGoodInner;
use WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200Response;
use WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmount;
use WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmountMetric;
use WWW::OpenAPIClient::Object::GetRecipeTasteByID200Response;
use WWW::OpenAPIClient::Object::GetShoppingList200Response;
use WWW::OpenAPIClient::Object::GetShoppingList200ResponseAislesInner;
use WWW::OpenAPIClient::Object::GetShoppingList200ResponseAislesInnerItemsInner;
use WWW::OpenAPIClient::Object::GetShoppingList200ResponseAislesInnerItemsInnerMeasures;
use WWW::OpenAPIClient::Object::GetSimilarRecipes200ResponseInner;
use WWW::OpenAPIClient::Object::GetWineDescription200Response;
use WWW::OpenAPIClient::Object::GetWinePairing200Response;
use WWW::OpenAPIClient::Object::GetWinePairing200ResponseProductMatchesInner;
use WWW::OpenAPIClient::Object::GetWineRecommendation200Response;
use WWW::OpenAPIClient::Object::GetWineRecommendation200ResponseRecommendedWinesInner;
use WWW::OpenAPIClient::Object::GuessNutritionByDishName200Response;
use WWW::OpenAPIClient::Object::GuessNutritionByDishName200ResponseCalories;
use WWW::OpenAPIClient::Object::GuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200Response;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseCategory;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseNutrition;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseNutritionCalories;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseNutritionCaloriesConfidenceRange95Percent;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseRecipesInner;
use WWW::OpenAPIClient::Object::ImageClassificationByURL200Response;
use WWW::OpenAPIClient::Object::IngredientSearch200Response;
use WWW::OpenAPIClient::Object::IngredientSearch200ResponseResultsInner;
use WWW::OpenAPIClient::Object::MapIngredientsToGroceryProducts200ResponseInner;
use WWW::OpenAPIClient::Object::MapIngredientsToGroceryProducts200ResponseInnerProductsInner;
use WWW::OpenAPIClient::Object::MapIngredientsToGroceryProductsRequest;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInner;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerEstimatedCost;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutrition;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionCaloricBreakdown;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionNutrientsInner;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionPropertiesInner;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionWeightPerServing;
use WWW::OpenAPIClient::Object::QuickAnswer200Response;
use WWW::OpenAPIClient::Object::SearchAllFood200Response;
use WWW::OpenAPIClient::Object::SearchAllFood200ResponseSearchResultsInner;
use WWW::OpenAPIClient::Object::SearchAllFood200ResponseSearchResultsInnerResultsInner;
use WWW::OpenAPIClient::Object::SearchCustomFoods200Response;
use WWW::OpenAPIClient::Object::SearchCustomFoods200ResponseCustomFoodsInner;
use WWW::OpenAPIClient::Object::SearchFoodVideos200Response;
use WWW::OpenAPIClient::Object::SearchFoodVideos200ResponseVideosInner;
use WWW::OpenAPIClient::Object::SearchGroceryProducts200Response;
use WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200Response;
use WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200ResponseNutrition;
use WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200ResponseServings;
use WWW::OpenAPIClient::Object::SearchMenuItems200Response;
use WWW::OpenAPIClient::Object::SearchMenuItems200ResponseMenuItemsInner;
use WWW::OpenAPIClient::Object::SearchRecipes200Response;
use WWW::OpenAPIClient::Object::SearchRecipes200ResponseResultsInner;
use WWW::OpenAPIClient::Object::SearchRecipesByIngredients200ResponseInner;
use WWW::OpenAPIClient::Object::SearchRecipesByIngredients200ResponseInnerMissedIngredientsInner;
use WWW::OpenAPIClient::Object::SearchRecipesByNutrients200ResponseInner;
use WWW::OpenAPIClient::Object::SearchRestaurants200Response;
use WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInner;
use WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInnerAddress;
use WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInnerLocalHours;
use WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational;
use WWW::OpenAPIClient::Object::SearchSiteContent200Response;
use WWW::OpenAPIClient::Object::SearchSiteContent200ResponseArticlesInner;
use WWW::OpenAPIClient::Object::SearchSiteContent200ResponseGroceryProductsInner;
use WWW::OpenAPIClient::Object::SearchSiteContent200ResponseGroceryProductsInnerDataPointsInner;
use WWW::OpenAPIClient::Object::SummarizeRecipe200Response;
use WWW::OpenAPIClient::Object::TalkToChatbot200Response;

````

# GETTING STARTED
Put the Perl SDK under the 'lib' folder in your project directory, then run the following
```perl
#!/usr/bin/perl
use lib 'lib';
use strict;
use warnings;
# load the API package
use WWW::OpenAPIClient::DefaultApi;
use WWW::OpenAPIClient::IngredientsApi;
use WWW::OpenAPIClient::MealPlanningApi;
use WWW::OpenAPIClient::MenuItemsApi;
use WWW::OpenAPIClient::MiscApi;
use WWW::OpenAPIClient::ProductsApi;
use WWW::OpenAPIClient::RecipesApi;
use WWW::OpenAPIClient::WineApi;

# load the models
use WWW::OpenAPIClient::Object::AddMealPlanTemplate200Response;
use WWW::OpenAPIClient::Object::AddMealPlanTemplate200ResponseItemsInner;
use WWW::OpenAPIClient::Object::AddMealPlanTemplate200ResponseItemsInnerValue;
use WWW::OpenAPIClient::Object::AddToMealPlanRequest;
use WWW::OpenAPIClient::Object::AddToMealPlanRequest1;
use WWW::OpenAPIClient::Object::AddToMealPlanRequest1Value;
use WWW::OpenAPIClient::Object::AddToMealPlanRequest1ValueIngredientsInner;
use WWW::OpenAPIClient::Object::AddToShoppingListRequest;
use WWW::OpenAPIClient::Object::AnalyzeARecipeSearchQuery200Response;
use WWW::OpenAPIClient::Object::AnalyzeARecipeSearchQuery200ResponseDishesInner;
use WWW::OpenAPIClient::Object::AnalyzeARecipeSearchQuery200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200Response;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseParsedInstructionsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner;
use WWW::OpenAPIClient::Object::AnalyzeRecipeRequest;
use WWW::OpenAPIClient::Object::AnalyzeRecipeRequest1;
use WWW::OpenAPIClient::Object::AutocompleteIngredientSearch200ResponseInner;
use WWW::OpenAPIClient::Object::AutocompleteMenuItemSearch200Response;
use WWW::OpenAPIClient::Object::AutocompleteProductSearch200Response;
use WWW::OpenAPIClient::Object::AutocompleteProductSearch200ResponseResultsInner;
use WWW::OpenAPIClient::Object::AutocompleteRecipeSearch200ResponseInner;
use WWW::OpenAPIClient::Object::ClassifyCuisine200Response;
use WWW::OpenAPIClient::Object::ClassifyGroceryProduct200Response;
use WWW::OpenAPIClient::Object::ClassifyGroceryProductBulk200ResponseInner;
use WWW::OpenAPIClient::Object::ClassifyGroceryProductBulkRequestInner;
use WWW::OpenAPIClient::Object::ClassifyGroceryProductRequest;
use WWW::OpenAPIClient::Object::ClearMealPlanDayRequest;
use WWW::OpenAPIClient::Object::ComputeGlycemicLoad200Response;
use WWW::OpenAPIClient::Object::ComputeGlycemicLoad200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::ComputeGlycemicLoadRequest;
use WWW::OpenAPIClient::Object::ComputeIngredientAmount200Response;
use WWW::OpenAPIClient::Object::ConnectUser200Response;
use WWW::OpenAPIClient::Object::ConnectUserRequest;
use WWW::OpenAPIClient::Object::ConvertAmounts200Response;
use WWW::OpenAPIClient::Object::CreateRecipeCard200Response;
use WWW::OpenAPIClient::Object::DeleteFromMealPlanRequest;
use WWW::OpenAPIClient::Object::DetectFoodInText200Response;
use WWW::OpenAPIClient::Object::DetectFoodInText200ResponseAnnotationsInner;
use WWW::OpenAPIClient::Object::GenerateMealPlan200Response;
use WWW::OpenAPIClient::Object::GenerateMealPlan200ResponseNutrients;
use WWW::OpenAPIClient::Object::GenerateShoppingList200Response;
use WWW::OpenAPIClient::Object::GenerateShoppingListRequest;
use WWW::OpenAPIClient::Object::GetARandomFoodJoke200Response;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200Response;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner;
use WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner;
use WWW::OpenAPIClient::Object::GetComparableProducts200Response;
use WWW::OpenAPIClient::Object::GetComparableProducts200ResponseComparableProducts;
use WWW::OpenAPIClient::Object::GetComparableProducts200ResponseComparableProductsProteinInner;
use WWW::OpenAPIClient::Object::GetConversationSuggests200Response;
use WWW::OpenAPIClient::Object::GetConversationSuggests200ResponseSuggests;
use WWW::OpenAPIClient::Object::GetConversationSuggests200ResponseSuggestsInner;
use WWW::OpenAPIClient::Object::GetDishPairingForWine200Response;
use WWW::OpenAPIClient::Object::GetIngredientInformation200Response;
use WWW::OpenAPIClient::Object::GetIngredientInformation200ResponseNutrition;
use WWW::OpenAPIClient::Object::GetIngredientSubstitutes200Response;
use WWW::OpenAPIClient::Object::GetMealPlanTemplate200Response;
use WWW::OpenAPIClient::Object::GetMealPlanTemplate200ResponseDaysInner;
use WWW::OpenAPIClient::Object::GetMealPlanTemplate200ResponseDaysInnerItemsInner;
use WWW::OpenAPIClient::Object::GetMealPlanTemplate200ResponseDaysInnerItemsInnerValue;
use WWW::OpenAPIClient::Object::GetMealPlanTemplates200Response;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200Response;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInner;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerItemsInner;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerItemsInnerValue;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerNutritionSummary;
use WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner;
use WWW::OpenAPIClient::Object::GetMenuItemInformation200Response;
use WWW::OpenAPIClient::Object::GetProductInformation200Response;
use WWW::OpenAPIClient::Object::GetProductInformation200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::GetRandomFoodTrivia200Response;
use WWW::OpenAPIClient::Object::GetRandomRecipes200Response;
use WWW::OpenAPIClient::Object::GetRandomRecipes200ResponseRecipesInner;
use WWW::OpenAPIClient::Object::GetRecipeEquipmentByID200Response;
use WWW::OpenAPIClient::Object::GetRecipeEquipmentByID200ResponseEquipmentInner;
use WWW::OpenAPIClient::Object::GetRecipeInformation200Response;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseExtendedIngredientsInner;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseExtendedIngredientsInnerMeasures;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseWinePairing;
use WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseWinePairingProductMatchesInner;
use WWW::OpenAPIClient::Object::GetRecipeInformationBulk200ResponseInner;
use WWW::OpenAPIClient::Object::GetRecipeIngredientsByID200Response;
use WWW::OpenAPIClient::Object::GetRecipeIngredientsByID200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::GetRecipeNutritionWidgetByID200Response;
use WWW::OpenAPIClient::Object::GetRecipeNutritionWidgetByID200ResponseBadInner;
use WWW::OpenAPIClient::Object::GetRecipeNutritionWidgetByID200ResponseGoodInner;
use WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200Response;
use WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmount;
use WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmountMetric;
use WWW::OpenAPIClient::Object::GetRecipeTasteByID200Response;
use WWW::OpenAPIClient::Object::GetShoppingList200Response;
use WWW::OpenAPIClient::Object::GetShoppingList200ResponseAislesInner;
use WWW::OpenAPIClient::Object::GetShoppingList200ResponseAislesInnerItemsInner;
use WWW::OpenAPIClient::Object::GetShoppingList200ResponseAislesInnerItemsInnerMeasures;
use WWW::OpenAPIClient::Object::GetSimilarRecipes200ResponseInner;
use WWW::OpenAPIClient::Object::GetWineDescription200Response;
use WWW::OpenAPIClient::Object::GetWinePairing200Response;
use WWW::OpenAPIClient::Object::GetWinePairing200ResponseProductMatchesInner;
use WWW::OpenAPIClient::Object::GetWineRecommendation200Response;
use WWW::OpenAPIClient::Object::GetWineRecommendation200ResponseRecommendedWinesInner;
use WWW::OpenAPIClient::Object::GuessNutritionByDishName200Response;
use WWW::OpenAPIClient::Object::GuessNutritionByDishName200ResponseCalories;
use WWW::OpenAPIClient::Object::GuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200Response;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseCategory;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseNutrition;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseNutritionCalories;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseNutritionCaloriesConfidenceRange95Percent;
use WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseRecipesInner;
use WWW::OpenAPIClient::Object::ImageClassificationByURL200Response;
use WWW::OpenAPIClient::Object::IngredientSearch200Response;
use WWW::OpenAPIClient::Object::IngredientSearch200ResponseResultsInner;
use WWW::OpenAPIClient::Object::MapIngredientsToGroceryProducts200ResponseInner;
use WWW::OpenAPIClient::Object::MapIngredientsToGroceryProducts200ResponseInnerProductsInner;
use WWW::OpenAPIClient::Object::MapIngredientsToGroceryProductsRequest;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInner;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerEstimatedCost;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutrition;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionCaloricBreakdown;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionNutrientsInner;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionPropertiesInner;
use WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionWeightPerServing;
use WWW::OpenAPIClient::Object::QuickAnswer200Response;
use WWW::OpenAPIClient::Object::SearchAllFood200Response;
use WWW::OpenAPIClient::Object::SearchAllFood200ResponseSearchResultsInner;
use WWW::OpenAPIClient::Object::SearchAllFood200ResponseSearchResultsInnerResultsInner;
use WWW::OpenAPIClient::Object::SearchCustomFoods200Response;
use WWW::OpenAPIClient::Object::SearchCustomFoods200ResponseCustomFoodsInner;
use WWW::OpenAPIClient::Object::SearchFoodVideos200Response;
use WWW::OpenAPIClient::Object::SearchFoodVideos200ResponseVideosInner;
use WWW::OpenAPIClient::Object::SearchGroceryProducts200Response;
use WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200Response;
use WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200ResponseNutrition;
use WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200ResponseServings;
use WWW::OpenAPIClient::Object::SearchMenuItems200Response;
use WWW::OpenAPIClient::Object::SearchMenuItems200ResponseMenuItemsInner;
use WWW::OpenAPIClient::Object::SearchRecipes200Response;
use WWW::OpenAPIClient::Object::SearchRecipes200ResponseResultsInner;
use WWW::OpenAPIClient::Object::SearchRecipesByIngredients200ResponseInner;
use WWW::OpenAPIClient::Object::SearchRecipesByIngredients200ResponseInnerMissedIngredientsInner;
use WWW::OpenAPIClient::Object::SearchRecipesByNutrients200ResponseInner;
use WWW::OpenAPIClient::Object::SearchRestaurants200Response;
use WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInner;
use WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInnerAddress;
use WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInnerLocalHours;
use WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational;
use WWW::OpenAPIClient::Object::SearchSiteContent200Response;
use WWW::OpenAPIClient::Object::SearchSiteContent200ResponseArticlesInner;
use WWW::OpenAPIClient::Object::SearchSiteContent200ResponseGroceryProductsInner;
use WWW::OpenAPIClient::Object::SearchSiteContent200ResponseGroceryProductsInnerDataPointsInner;
use WWW::OpenAPIClient::Object::SummarizeRecipe200Response;
use WWW::OpenAPIClient::Object::TalkToChatbot200Response;

# for displaying the API response data
use Data::Dumper;


my $api_instance = WWW::OpenAPIClient::DefaultApi->new(
    # Configure API key authorization: apiKeyScheme
    api_key => {'x-api-key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'x-api-key' => 'Bearer'},
);

my $analyze_recipe_request = WWW::OpenAPIClient::Object::AnalyzeRecipeRequest->new(); # AnalyzeRecipeRequest | Example request body.
my $language = en; # string | The input language, either \"en\" or \"de\".
my $include_nutrition = false; # boolean | Whether nutrition data should be added to correctly parsed ingredients.
my $include_taste = false; # boolean | Whether taste data should be added to correctly parsed ingredients.

eval {
    my $result = $api_instance->analyze_recipe(analyze_recipe_request => $analyze_recipe_request, language => $language, include_nutrition => $include_nutrition, include_taste => $include_taste);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling DefaultApi->analyze_recipe: $@\n";
}

```

# DOCUMENTATION FOR API ENDPOINTS

All URIs are relative to *https://api.spoonacular.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**analyze_recipe**](docs/DefaultApi.md#analyze_recipe) | **POST** /recipes/analyze | Analyze Recipe
*DefaultApi* | [**create_recipe_card_get**](docs/DefaultApi.md#create_recipe_card_get) | **GET** /recipes/{id}/card | Create Recipe Card
*DefaultApi* | [**search_restaurants**](docs/DefaultApi.md#search_restaurants) | **GET** /food/restaurants/search | Search Restaurants
*IngredientsApi* | [**autocomplete_ingredient_search**](docs/IngredientsApi.md#autocomplete_ingredient_search) | **GET** /food/ingredients/autocomplete | Autocomplete Ingredient Search
*IngredientsApi* | [**compute_ingredient_amount**](docs/IngredientsApi.md#compute_ingredient_amount) | **GET** /food/ingredients/{id}/amount | Compute Ingredient Amount
*IngredientsApi* | [**get_ingredient_information**](docs/IngredientsApi.md#get_ingredient_information) | **GET** /food/ingredients/{id}/information | Get Ingredient Information
*IngredientsApi* | [**get_ingredient_substitutes**](docs/IngredientsApi.md#get_ingredient_substitutes) | **GET** /food/ingredients/substitutes | Get Ingredient Substitutes
*IngredientsApi* | [**get_ingredient_substitutes_by_id**](docs/IngredientsApi.md#get_ingredient_substitutes_by_id) | **GET** /food/ingredients/{id}/substitutes | Get Ingredient Substitutes by ID
*IngredientsApi* | [**ingredient_search**](docs/IngredientsApi.md#ingredient_search) | **GET** /food/ingredients/search | Ingredient Search
*IngredientsApi* | [**ingredients_by_id_image**](docs/IngredientsApi.md#ingredients_by_id_image) | **GET** /recipes/{id}/ingredientWidget.png | Ingredients by ID Image
*IngredientsApi* | [**map_ingredients_to_grocery_products**](docs/IngredientsApi.md#map_ingredients_to_grocery_products) | **POST** /food/ingredients/map | Map Ingredients to Grocery Products
*IngredientsApi* | [**visualize_ingredients**](docs/IngredientsApi.md#visualize_ingredients) | **POST** /recipes/visualizeIngredients | Ingredients Widget
*MealPlanningApi* | [**add_meal_plan_template**](docs/MealPlanningApi.md#add_meal_plan_template) | **POST** /mealplanner/{username}/templates | Add Meal Plan Template
*MealPlanningApi* | [**add_to_meal_plan**](docs/MealPlanningApi.md#add_to_meal_plan) | **POST** /mealplanner/{username}/items | Add to Meal Plan
*MealPlanningApi* | [**add_to_shopping_list**](docs/MealPlanningApi.md#add_to_shopping_list) | **POST** /mealplanner/{username}/shopping-list/items | Add to Shopping List
*MealPlanningApi* | [**clear_meal_plan_day**](docs/MealPlanningApi.md#clear_meal_plan_day) | **DELETE** /mealplanner/{username}/day/{date} | Clear Meal Plan Day
*MealPlanningApi* | [**connect_user**](docs/MealPlanningApi.md#connect_user) | **POST** /users/connect | Connect User
*MealPlanningApi* | [**delete_from_meal_plan**](docs/MealPlanningApi.md#delete_from_meal_plan) | **DELETE** /mealplanner/{username}/items/{id} | Delete from Meal Plan
*MealPlanningApi* | [**delete_from_shopping_list**](docs/MealPlanningApi.md#delete_from_shopping_list) | **DELETE** /mealplanner/{username}/shopping-list/items/{id} | Delete from Shopping List
*MealPlanningApi* | [**delete_meal_plan_template**](docs/MealPlanningApi.md#delete_meal_plan_template) | **DELETE** /mealplanner/{username}/templates/{id} | Delete Meal Plan Template
*MealPlanningApi* | [**generate_meal_plan**](docs/MealPlanningApi.md#generate_meal_plan) | **GET** /mealplanner/generate | Generate Meal Plan
*MealPlanningApi* | [**generate_shopping_list**](docs/MealPlanningApi.md#generate_shopping_list) | **POST** /mealplanner/{username}/shopping-list/{start-date}/{end-date} | Generate Shopping List
*MealPlanningApi* | [**get_meal_plan_template**](docs/MealPlanningApi.md#get_meal_plan_template) | **GET** /mealplanner/{username}/templates/{id} | Get Meal Plan Template
*MealPlanningApi* | [**get_meal_plan_templates**](docs/MealPlanningApi.md#get_meal_plan_templates) | **GET** /mealplanner/{username}/templates | Get Meal Plan Templates
*MealPlanningApi* | [**get_meal_plan_week**](docs/MealPlanningApi.md#get_meal_plan_week) | **GET** /mealplanner/{username}/week/{start-date} | Get Meal Plan Week
*MealPlanningApi* | [**get_shopping_list**](docs/MealPlanningApi.md#get_shopping_list) | **GET** /mealplanner/{username}/shopping-list | Get Shopping List
*MenuItemsApi* | [**autocomplete_menu_item_search**](docs/MenuItemsApi.md#autocomplete_menu_item_search) | **GET** /food/menuItems/suggest | Autocomplete Menu Item Search
*MenuItemsApi* | [**get_menu_item_information**](docs/MenuItemsApi.md#get_menu_item_information) | **GET** /food/menuItems/{id} | Get Menu Item Information
*MenuItemsApi* | [**menu_item_nutrition_by_id_image**](docs/MenuItemsApi.md#menu_item_nutrition_by_id_image) | **GET** /food/menuItems/{id}/nutritionWidget.png | Menu Item Nutrition by ID Image
*MenuItemsApi* | [**menu_item_nutrition_label_image**](docs/MenuItemsApi.md#menu_item_nutrition_label_image) | **GET** /food/menuItems/{id}/nutritionLabel.png | Menu Item Nutrition Label Image
*MenuItemsApi* | [**menu_item_nutrition_label_widget**](docs/MenuItemsApi.md#menu_item_nutrition_label_widget) | **GET** /food/menuItems/{id}/nutritionLabel | Menu Item Nutrition Label Widget
*MenuItemsApi* | [**search_menu_items**](docs/MenuItemsApi.md#search_menu_items) | **GET** /food/menuItems/search | Search Menu Items
*MenuItemsApi* | [**visualize_menu_item_nutrition_by_id**](docs/MenuItemsApi.md#visualize_menu_item_nutrition_by_id) | **GET** /food/menuItems/{id}/nutritionWidget | Menu Item Nutrition by ID Widget
*MiscApi* | [**detect_food_in_text**](docs/MiscApi.md#detect_food_in_text) | **POST** /food/detect | Detect Food in Text
*MiscApi* | [**get_a_random_food_joke**](docs/MiscApi.md#get_a_random_food_joke) | **GET** /food/jokes/random | Random Food Joke
*MiscApi* | [**get_conversation_suggests**](docs/MiscApi.md#get_conversation_suggests) | **GET** /food/converse/suggest | Conversation Suggests
*MiscApi* | [**get_random_food_trivia**](docs/MiscApi.md#get_random_food_trivia) | **GET** /food/trivia/random | Random Food Trivia
*MiscApi* | [**image_analysis_by_url**](docs/MiscApi.md#image_analysis_by_url) | **GET** /food/images/analyze | Image Analysis by URL
*MiscApi* | [**image_classification_by_url**](docs/MiscApi.md#image_classification_by_url) | **GET** /food/images/classify | Image Classification by URL
*MiscApi* | [**search_all_food**](docs/MiscApi.md#search_all_food) | **GET** /food/search | Search All Food
*MiscApi* | [**search_custom_foods**](docs/MiscApi.md#search_custom_foods) | **GET** /food/customFoods/search | Search Custom Foods
*MiscApi* | [**search_food_videos**](docs/MiscApi.md#search_food_videos) | **GET** /food/videos/search | Search Food Videos
*MiscApi* | [**search_site_content**](docs/MiscApi.md#search_site_content) | **GET** /food/site/search | Search Site Content
*MiscApi* | [**talk_to_chatbot**](docs/MiscApi.md#talk_to_chatbot) | **GET** /food/converse | Talk to Chatbot
*ProductsApi* | [**autocomplete_product_search**](docs/ProductsApi.md#autocomplete_product_search) | **GET** /food/products/suggest | Autocomplete Product Search
*ProductsApi* | [**classify_grocery_product**](docs/ProductsApi.md#classify_grocery_product) | **POST** /food/products/classify | Classify Grocery Product
*ProductsApi* | [**classify_grocery_product_bulk**](docs/ProductsApi.md#classify_grocery_product_bulk) | **POST** /food/products/classifyBatch | Classify Grocery Product Bulk
*ProductsApi* | [**get_comparable_products**](docs/ProductsApi.md#get_comparable_products) | **GET** /food/products/upc/{upc}/comparable | Get Comparable Products
*ProductsApi* | [**get_product_information**](docs/ProductsApi.md#get_product_information) | **GET** /food/products/{id} | Get Product Information
*ProductsApi* | [**product_nutrition_by_id_image**](docs/ProductsApi.md#product_nutrition_by_id_image) | **GET** /food/products/{id}/nutritionWidget.png | Product Nutrition by ID Image
*ProductsApi* | [**product_nutrition_label_image**](docs/ProductsApi.md#product_nutrition_label_image) | **GET** /food/products/{id}/nutritionLabel.png | Product Nutrition Label Image
*ProductsApi* | [**product_nutrition_label_widget**](docs/ProductsApi.md#product_nutrition_label_widget) | **GET** /food/products/{id}/nutritionLabel | Product Nutrition Label Widget
*ProductsApi* | [**search_grocery_products**](docs/ProductsApi.md#search_grocery_products) | **GET** /food/products/search | Search Grocery Products
*ProductsApi* | [**search_grocery_products_by_upc**](docs/ProductsApi.md#search_grocery_products_by_upc) | **GET** /food/products/upc/{upc} | Search Grocery Products by UPC
*ProductsApi* | [**visualize_product_nutrition_by_id**](docs/ProductsApi.md#visualize_product_nutrition_by_id) | **GET** /food/products/{id}/nutritionWidget | Product Nutrition by ID Widget
*RecipesApi* | [**analyze_a_recipe_search_query**](docs/RecipesApi.md#analyze_a_recipe_search_query) | **GET** /recipes/queries/analyze | Analyze a Recipe Search Query
*RecipesApi* | [**analyze_recipe_instructions**](docs/RecipesApi.md#analyze_recipe_instructions) | **POST** /recipes/analyzeInstructions | Analyze Recipe Instructions
*RecipesApi* | [**autocomplete_recipe_search**](docs/RecipesApi.md#autocomplete_recipe_search) | **GET** /recipes/autocomplete | Autocomplete Recipe Search
*RecipesApi* | [**classify_cuisine**](docs/RecipesApi.md#classify_cuisine) | **POST** /recipes/cuisine | Classify Cuisine
*RecipesApi* | [**compute_glycemic_load**](docs/RecipesApi.md#compute_glycemic_load) | **POST** /food/ingredients/glycemicLoad | Compute Glycemic Load
*RecipesApi* | [**convert_amounts**](docs/RecipesApi.md#convert_amounts) | **GET** /recipes/convert | Convert Amounts
*RecipesApi* | [**create_recipe_card**](docs/RecipesApi.md#create_recipe_card) | **POST** /recipes/visualizeRecipe | Create Recipe Card
*RecipesApi* | [**equipment_by_id_image**](docs/RecipesApi.md#equipment_by_id_image) | **GET** /recipes/{id}/equipmentWidget.png | Equipment by ID Image
*RecipesApi* | [**extract_recipe_from_website**](docs/RecipesApi.md#extract_recipe_from_website) | **GET** /recipes/extract | Extract Recipe from Website
*RecipesApi* | [**get_analyzed_recipe_instructions**](docs/RecipesApi.md#get_analyzed_recipe_instructions) | **GET** /recipes/{id}/analyzedInstructions | Get Analyzed Recipe Instructions
*RecipesApi* | [**get_random_recipes**](docs/RecipesApi.md#get_random_recipes) | **GET** /recipes/random | Get Random Recipes
*RecipesApi* | [**get_recipe_equipment_by_id**](docs/RecipesApi.md#get_recipe_equipment_by_id) | **GET** /recipes/{id}/equipmentWidget.json | Equipment by ID
*RecipesApi* | [**get_recipe_information**](docs/RecipesApi.md#get_recipe_information) | **GET** /recipes/{id}/information | Get Recipe Information
*RecipesApi* | [**get_recipe_information_bulk**](docs/RecipesApi.md#get_recipe_information_bulk) | **GET** /recipes/informationBulk | Get Recipe Information Bulk
*RecipesApi* | [**get_recipe_ingredients_by_id**](docs/RecipesApi.md#get_recipe_ingredients_by_id) | **GET** /recipes/{id}/ingredientWidget.json | Ingredients by ID
*RecipesApi* | [**get_recipe_nutrition_widget_by_id**](docs/RecipesApi.md#get_recipe_nutrition_widget_by_id) | **GET** /recipes/{id}/nutritionWidget.json | Nutrition by ID
*RecipesApi* | [**get_recipe_price_breakdown_by_id**](docs/RecipesApi.md#get_recipe_price_breakdown_by_id) | **GET** /recipes/{id}/priceBreakdownWidget.json | Price Breakdown by ID
*RecipesApi* | [**get_recipe_taste_by_id**](docs/RecipesApi.md#get_recipe_taste_by_id) | **GET** /recipes/{id}/tasteWidget.json | Taste by ID
*RecipesApi* | [**get_similar_recipes**](docs/RecipesApi.md#get_similar_recipes) | **GET** /recipes/{id}/similar | Get Similar Recipes
*RecipesApi* | [**guess_nutrition_by_dish_name**](docs/RecipesApi.md#guess_nutrition_by_dish_name) | **GET** /recipes/guessNutrition | Guess Nutrition by Dish Name
*RecipesApi* | [**ingredients_by_id_image**](docs/RecipesApi.md#ingredients_by_id_image) | **GET** /recipes/{id}/ingredientWidget.png | Ingredients by ID Image
*RecipesApi* | [**parse_ingredients**](docs/RecipesApi.md#parse_ingredients) | **POST** /recipes/parseIngredients | Parse Ingredients
*RecipesApi* | [**price_breakdown_by_id_image**](docs/RecipesApi.md#price_breakdown_by_id_image) | **GET** /recipes/{id}/priceBreakdownWidget.png | Price Breakdown by ID Image
*RecipesApi* | [**quick_answer**](docs/RecipesApi.md#quick_answer) | **GET** /recipes/quickAnswer | Quick Answer
*RecipesApi* | [**recipe_nutrition_by_id_image**](docs/RecipesApi.md#recipe_nutrition_by_id_image) | **GET** /recipes/{id}/nutritionWidget.png | Recipe Nutrition by ID Image
*RecipesApi* | [**recipe_nutrition_label_image**](docs/RecipesApi.md#recipe_nutrition_label_image) | **GET** /recipes/{id}/nutritionLabel.png | Recipe Nutrition Label Image
*RecipesApi* | [**recipe_nutrition_label_widget**](docs/RecipesApi.md#recipe_nutrition_label_widget) | **GET** /recipes/{id}/nutritionLabel | Recipe Nutrition Label Widget
*RecipesApi* | [**recipe_taste_by_id_image**](docs/RecipesApi.md#recipe_taste_by_id_image) | **GET** /recipes/{id}/tasteWidget.png | Recipe Taste by ID Image
*RecipesApi* | [**search_recipes**](docs/RecipesApi.md#search_recipes) | **GET** /recipes/complexSearch | Search Recipes
*RecipesApi* | [**search_recipes_by_ingredients**](docs/RecipesApi.md#search_recipes_by_ingredients) | **GET** /recipes/findByIngredients | Search Recipes by Ingredients
*RecipesApi* | [**search_recipes_by_nutrients**](docs/RecipesApi.md#search_recipes_by_nutrients) | **GET** /recipes/findByNutrients | Search Recipes by Nutrients
*RecipesApi* | [**summarize_recipe**](docs/RecipesApi.md#summarize_recipe) | **GET** /recipes/{id}/summary | Summarize Recipe
*RecipesApi* | [**visualize_equipment**](docs/RecipesApi.md#visualize_equipment) | **POST** /recipes/visualizeEquipment | Equipment Widget
*RecipesApi* | [**visualize_price_breakdown**](docs/RecipesApi.md#visualize_price_breakdown) | **POST** /recipes/visualizePriceEstimator | Price Breakdown Widget
*RecipesApi* | [**visualize_recipe_equipment_by_id**](docs/RecipesApi.md#visualize_recipe_equipment_by_id) | **GET** /recipes/{id}/equipmentWidget | Equipment by ID Widget
*RecipesApi* | [**visualize_recipe_ingredients_by_id**](docs/RecipesApi.md#visualize_recipe_ingredients_by_id) | **GET** /recipes/{id}/ingredientWidget | Ingredients by ID Widget
*RecipesApi* | [**visualize_recipe_nutrition**](docs/RecipesApi.md#visualize_recipe_nutrition) | **POST** /recipes/visualizeNutrition | Recipe Nutrition Widget
*RecipesApi* | [**visualize_recipe_nutrition_by_id**](docs/RecipesApi.md#visualize_recipe_nutrition_by_id) | **GET** /recipes/{id}/nutritionWidget | Recipe Nutrition by ID Widget
*RecipesApi* | [**visualize_recipe_price_breakdown_by_id**](docs/RecipesApi.md#visualize_recipe_price_breakdown_by_id) | **GET** /recipes/{id}/priceBreakdownWidget | Price Breakdown by ID Widget
*RecipesApi* | [**visualize_recipe_taste**](docs/RecipesApi.md#visualize_recipe_taste) | **POST** /recipes/visualizeTaste | Recipe Taste Widget
*RecipesApi* | [**visualize_recipe_taste_by_id**](docs/RecipesApi.md#visualize_recipe_taste_by_id) | **GET** /recipes/{id}/tasteWidget | Recipe Taste by ID Widget
*WineApi* | [**get_dish_pairing_for_wine**](docs/WineApi.md#get_dish_pairing_for_wine) | **GET** /food/wine/dishes | Dish Pairing for Wine
*WineApi* | [**get_wine_description**](docs/WineApi.md#get_wine_description) | **GET** /food/wine/description | Wine Description
*WineApi* | [**get_wine_pairing**](docs/WineApi.md#get_wine_pairing) | **GET** /food/wine/pairing | Wine Pairing
*WineApi* | [**get_wine_recommendation**](docs/WineApi.md#get_wine_recommendation) | **GET** /food/wine/recommendation | Wine Recommendation


# DOCUMENTATION FOR MODELS
 - [WWW::OpenAPIClient::Object::AddMealPlanTemplate200Response](docs/AddMealPlanTemplate200Response.md)
 - [WWW::OpenAPIClient::Object::AddMealPlanTemplate200ResponseItemsInner](docs/AddMealPlanTemplate200ResponseItemsInner.md)
 - [WWW::OpenAPIClient::Object::AddMealPlanTemplate200ResponseItemsInnerValue](docs/AddMealPlanTemplate200ResponseItemsInnerValue.md)
 - [WWW::OpenAPIClient::Object::AddToMealPlanRequest](docs/AddToMealPlanRequest.md)
 - [WWW::OpenAPIClient::Object::AddToMealPlanRequest1](docs/AddToMealPlanRequest1.md)
 - [WWW::OpenAPIClient::Object::AddToMealPlanRequest1Value](docs/AddToMealPlanRequest1Value.md)
 - [WWW::OpenAPIClient::Object::AddToMealPlanRequest1ValueIngredientsInner](docs/AddToMealPlanRequest1ValueIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::AddToShoppingListRequest](docs/AddToShoppingListRequest.md)
 - [WWW::OpenAPIClient::Object::AnalyzeARecipeSearchQuery200Response](docs/AnalyzeARecipeSearchQuery200Response.md)
 - [WWW::OpenAPIClient::Object::AnalyzeARecipeSearchQuery200ResponseDishesInner](docs/AnalyzeARecipeSearchQuery200ResponseDishesInner.md)
 - [WWW::OpenAPIClient::Object::AnalyzeARecipeSearchQuery200ResponseIngredientsInner](docs/AnalyzeARecipeSearchQuery200ResponseIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200Response](docs/AnalyzeRecipeInstructions200Response.md)
 - [WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseIngredientsInner](docs/AnalyzeRecipeInstructions200ResponseIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseParsedInstructionsInner](docs/AnalyzeRecipeInstructions200ResponseParsedInstructionsInner.md)
 - [WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner](docs/AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.md)
 - [WWW::OpenAPIClient::Object::AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner](docs/AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::AnalyzeRecipeRequest](docs/AnalyzeRecipeRequest.md)
 - [WWW::OpenAPIClient::Object::AnalyzeRecipeRequest1](docs/AnalyzeRecipeRequest1.md)
 - [WWW::OpenAPIClient::Object::AutocompleteIngredientSearch200ResponseInner](docs/AutocompleteIngredientSearch200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::AutocompleteMenuItemSearch200Response](docs/AutocompleteMenuItemSearch200Response.md)
 - [WWW::OpenAPIClient::Object::AutocompleteProductSearch200Response](docs/AutocompleteProductSearch200Response.md)
 - [WWW::OpenAPIClient::Object::AutocompleteProductSearch200ResponseResultsInner](docs/AutocompleteProductSearch200ResponseResultsInner.md)
 - [WWW::OpenAPIClient::Object::AutocompleteRecipeSearch200ResponseInner](docs/AutocompleteRecipeSearch200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::ClassifyCuisine200Response](docs/ClassifyCuisine200Response.md)
 - [WWW::OpenAPIClient::Object::ClassifyGroceryProduct200Response](docs/ClassifyGroceryProduct200Response.md)
 - [WWW::OpenAPIClient::Object::ClassifyGroceryProductBulk200ResponseInner](docs/ClassifyGroceryProductBulk200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::ClassifyGroceryProductBulkRequestInner](docs/ClassifyGroceryProductBulkRequestInner.md)
 - [WWW::OpenAPIClient::Object::ClassifyGroceryProductRequest](docs/ClassifyGroceryProductRequest.md)
 - [WWW::OpenAPIClient::Object::ClearMealPlanDayRequest](docs/ClearMealPlanDayRequest.md)
 - [WWW::OpenAPIClient::Object::ComputeGlycemicLoad200Response](docs/ComputeGlycemicLoad200Response.md)
 - [WWW::OpenAPIClient::Object::ComputeGlycemicLoad200ResponseIngredientsInner](docs/ComputeGlycemicLoad200ResponseIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::ComputeGlycemicLoadRequest](docs/ComputeGlycemicLoadRequest.md)
 - [WWW::OpenAPIClient::Object::ComputeIngredientAmount200Response](docs/ComputeIngredientAmount200Response.md)
 - [WWW::OpenAPIClient::Object::ConnectUser200Response](docs/ConnectUser200Response.md)
 - [WWW::OpenAPIClient::Object::ConnectUserRequest](docs/ConnectUserRequest.md)
 - [WWW::OpenAPIClient::Object::ConvertAmounts200Response](docs/ConvertAmounts200Response.md)
 - [WWW::OpenAPIClient::Object::CreateRecipeCard200Response](docs/CreateRecipeCard200Response.md)
 - [WWW::OpenAPIClient::Object::DeleteFromMealPlanRequest](docs/DeleteFromMealPlanRequest.md)
 - [WWW::OpenAPIClient::Object::DetectFoodInText200Response](docs/DetectFoodInText200Response.md)
 - [WWW::OpenAPIClient::Object::DetectFoodInText200ResponseAnnotationsInner](docs/DetectFoodInText200ResponseAnnotationsInner.md)
 - [WWW::OpenAPIClient::Object::GenerateMealPlan200Response](docs/GenerateMealPlan200Response.md)
 - [WWW::OpenAPIClient::Object::GenerateMealPlan200ResponseNutrients](docs/GenerateMealPlan200ResponseNutrients.md)
 - [WWW::OpenAPIClient::Object::GenerateShoppingList200Response](docs/GenerateShoppingList200Response.md)
 - [WWW::OpenAPIClient::Object::GenerateShoppingListRequest](docs/GenerateShoppingListRequest.md)
 - [WWW::OpenAPIClient::Object::GetARandomFoodJoke200Response](docs/GetARandomFoodJoke200Response.md)
 - [WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200Response](docs/GetAnalyzedRecipeInstructions200Response.md)
 - [WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseIngredientsInner](docs/GetAnalyzedRecipeInstructions200ResponseIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner](docs/GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner.md)
 - [WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner](docs/GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.md)
 - [WWW::OpenAPIClient::Object::GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner](docs/GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::GetComparableProducts200Response](docs/GetComparableProducts200Response.md)
 - [WWW::OpenAPIClient::Object::GetComparableProducts200ResponseComparableProducts](docs/GetComparableProducts200ResponseComparableProducts.md)
 - [WWW::OpenAPIClient::Object::GetComparableProducts200ResponseComparableProductsProteinInner](docs/GetComparableProducts200ResponseComparableProductsProteinInner.md)
 - [WWW::OpenAPIClient::Object::GetConversationSuggests200Response](docs/GetConversationSuggests200Response.md)
 - [WWW::OpenAPIClient::Object::GetConversationSuggests200ResponseSuggests](docs/GetConversationSuggests200ResponseSuggests.md)
 - [WWW::OpenAPIClient::Object::GetConversationSuggests200ResponseSuggestsInner](docs/GetConversationSuggests200ResponseSuggestsInner.md)
 - [WWW::OpenAPIClient::Object::GetDishPairingForWine200Response](docs/GetDishPairingForWine200Response.md)
 - [WWW::OpenAPIClient::Object::GetIngredientInformation200Response](docs/GetIngredientInformation200Response.md)
 - [WWW::OpenAPIClient::Object::GetIngredientInformation200ResponseNutrition](docs/GetIngredientInformation200ResponseNutrition.md)
 - [WWW::OpenAPIClient::Object::GetIngredientSubstitutes200Response](docs/GetIngredientSubstitutes200Response.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanTemplate200Response](docs/GetMealPlanTemplate200Response.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanTemplate200ResponseDaysInner](docs/GetMealPlanTemplate200ResponseDaysInner.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanTemplate200ResponseDaysInnerItemsInner](docs/GetMealPlanTemplate200ResponseDaysInnerItemsInner.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanTemplate200ResponseDaysInnerItemsInnerValue](docs/GetMealPlanTemplate200ResponseDaysInnerItemsInnerValue.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanTemplates200Response](docs/GetMealPlanTemplates200Response.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanWeek200Response](docs/GetMealPlanWeek200Response.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInner](docs/GetMealPlanWeek200ResponseDaysInner.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerItemsInner](docs/GetMealPlanWeek200ResponseDaysInnerItemsInner.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerItemsInnerValue](docs/GetMealPlanWeek200ResponseDaysInnerItemsInnerValue.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerNutritionSummary](docs/GetMealPlanWeek200ResponseDaysInnerNutritionSummary.md)
 - [WWW::OpenAPIClient::Object::GetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner](docs/GetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner.md)
 - [WWW::OpenAPIClient::Object::GetMenuItemInformation200Response](docs/GetMenuItemInformation200Response.md)
 - [WWW::OpenAPIClient::Object::GetProductInformation200Response](docs/GetProductInformation200Response.md)
 - [WWW::OpenAPIClient::Object::GetProductInformation200ResponseIngredientsInner](docs/GetProductInformation200ResponseIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::GetRandomFoodTrivia200Response](docs/GetRandomFoodTrivia200Response.md)
 - [WWW::OpenAPIClient::Object::GetRandomRecipes200Response](docs/GetRandomRecipes200Response.md)
 - [WWW::OpenAPIClient::Object::GetRandomRecipes200ResponseRecipesInner](docs/GetRandomRecipes200ResponseRecipesInner.md)
 - [WWW::OpenAPIClient::Object::GetRecipeEquipmentByID200Response](docs/GetRecipeEquipmentByID200Response.md)
 - [WWW::OpenAPIClient::Object::GetRecipeEquipmentByID200ResponseEquipmentInner](docs/GetRecipeEquipmentByID200ResponseEquipmentInner.md)
 - [WWW::OpenAPIClient::Object::GetRecipeInformation200Response](docs/GetRecipeInformation200Response.md)
 - [WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseExtendedIngredientsInner](docs/GetRecipeInformation200ResponseExtendedIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseExtendedIngredientsInnerMeasures](docs/GetRecipeInformation200ResponseExtendedIngredientsInnerMeasures.md)
 - [WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric](docs/GetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric.md)
 - [WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseWinePairing](docs/GetRecipeInformation200ResponseWinePairing.md)
 - [WWW::OpenAPIClient::Object::GetRecipeInformation200ResponseWinePairingProductMatchesInner](docs/GetRecipeInformation200ResponseWinePairingProductMatchesInner.md)
 - [WWW::OpenAPIClient::Object::GetRecipeInformationBulk200ResponseInner](docs/GetRecipeInformationBulk200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::GetRecipeIngredientsByID200Response](docs/GetRecipeIngredientsByID200Response.md)
 - [WWW::OpenAPIClient::Object::GetRecipeIngredientsByID200ResponseIngredientsInner](docs/GetRecipeIngredientsByID200ResponseIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::GetRecipeNutritionWidgetByID200Response](docs/GetRecipeNutritionWidgetByID200Response.md)
 - [WWW::OpenAPIClient::Object::GetRecipeNutritionWidgetByID200ResponseBadInner](docs/GetRecipeNutritionWidgetByID200ResponseBadInner.md)
 - [WWW::OpenAPIClient::Object::GetRecipeNutritionWidgetByID200ResponseGoodInner](docs/GetRecipeNutritionWidgetByID200ResponseGoodInner.md)
 - [WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200Response](docs/GetRecipePriceBreakdownByID200Response.md)
 - [WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200ResponseIngredientsInner](docs/GetRecipePriceBreakdownByID200ResponseIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmount](docs/GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmount.md)
 - [WWW::OpenAPIClient::Object::GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmountMetric](docs/GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmountMetric.md)
 - [WWW::OpenAPIClient::Object::GetRecipeTasteByID200Response](docs/GetRecipeTasteByID200Response.md)
 - [WWW::OpenAPIClient::Object::GetShoppingList200Response](docs/GetShoppingList200Response.md)
 - [WWW::OpenAPIClient::Object::GetShoppingList200ResponseAislesInner](docs/GetShoppingList200ResponseAislesInner.md)
 - [WWW::OpenAPIClient::Object::GetShoppingList200ResponseAislesInnerItemsInner](docs/GetShoppingList200ResponseAislesInnerItemsInner.md)
 - [WWW::OpenAPIClient::Object::GetShoppingList200ResponseAislesInnerItemsInnerMeasures](docs/GetShoppingList200ResponseAislesInnerItemsInnerMeasures.md)
 - [WWW::OpenAPIClient::Object::GetSimilarRecipes200ResponseInner](docs/GetSimilarRecipes200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::GetWineDescription200Response](docs/GetWineDescription200Response.md)
 - [WWW::OpenAPIClient::Object::GetWinePairing200Response](docs/GetWinePairing200Response.md)
 - [WWW::OpenAPIClient::Object::GetWinePairing200ResponseProductMatchesInner](docs/GetWinePairing200ResponseProductMatchesInner.md)
 - [WWW::OpenAPIClient::Object::GetWineRecommendation200Response](docs/GetWineRecommendation200Response.md)
 - [WWW::OpenAPIClient::Object::GetWineRecommendation200ResponseRecommendedWinesInner](docs/GetWineRecommendation200ResponseRecommendedWinesInner.md)
 - [WWW::OpenAPIClient::Object::GuessNutritionByDishName200Response](docs/GuessNutritionByDishName200Response.md)
 - [WWW::OpenAPIClient::Object::GuessNutritionByDishName200ResponseCalories](docs/GuessNutritionByDishName200ResponseCalories.md)
 - [WWW::OpenAPIClient::Object::GuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent](docs/GuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent.md)
 - [WWW::OpenAPIClient::Object::ImageAnalysisByURL200Response](docs/ImageAnalysisByURL200Response.md)
 - [WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseCategory](docs/ImageAnalysisByURL200ResponseCategory.md)
 - [WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseNutrition](docs/ImageAnalysisByURL200ResponseNutrition.md)
 - [WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseNutritionCalories](docs/ImageAnalysisByURL200ResponseNutritionCalories.md)
 - [WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseNutritionCaloriesConfidenceRange95Percent](docs/ImageAnalysisByURL200ResponseNutritionCaloriesConfidenceRange95Percent.md)
 - [WWW::OpenAPIClient::Object::ImageAnalysisByURL200ResponseRecipesInner](docs/ImageAnalysisByURL200ResponseRecipesInner.md)
 - [WWW::OpenAPIClient::Object::ImageClassificationByURL200Response](docs/ImageClassificationByURL200Response.md)
 - [WWW::OpenAPIClient::Object::IngredientSearch200Response](docs/IngredientSearch200Response.md)
 - [WWW::OpenAPIClient::Object::IngredientSearch200ResponseResultsInner](docs/IngredientSearch200ResponseResultsInner.md)
 - [WWW::OpenAPIClient::Object::MapIngredientsToGroceryProducts200ResponseInner](docs/MapIngredientsToGroceryProducts200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::MapIngredientsToGroceryProducts200ResponseInnerProductsInner](docs/MapIngredientsToGroceryProducts200ResponseInnerProductsInner.md)
 - [WWW::OpenAPIClient::Object::MapIngredientsToGroceryProductsRequest](docs/MapIngredientsToGroceryProductsRequest.md)
 - [WWW::OpenAPIClient::Object::ParseIngredients200ResponseInner](docs/ParseIngredients200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerEstimatedCost](docs/ParseIngredients200ResponseInnerEstimatedCost.md)
 - [WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutrition](docs/ParseIngredients200ResponseInnerNutrition.md)
 - [WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionCaloricBreakdown](docs/ParseIngredients200ResponseInnerNutritionCaloricBreakdown.md)
 - [WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionNutrientsInner](docs/ParseIngredients200ResponseInnerNutritionNutrientsInner.md)
 - [WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionPropertiesInner](docs/ParseIngredients200ResponseInnerNutritionPropertiesInner.md)
 - [WWW::OpenAPIClient::Object::ParseIngredients200ResponseInnerNutritionWeightPerServing](docs/ParseIngredients200ResponseInnerNutritionWeightPerServing.md)
 - [WWW::OpenAPIClient::Object::QuickAnswer200Response](docs/QuickAnswer200Response.md)
 - [WWW::OpenAPIClient::Object::SearchAllFood200Response](docs/SearchAllFood200Response.md)
 - [WWW::OpenAPIClient::Object::SearchAllFood200ResponseSearchResultsInner](docs/SearchAllFood200ResponseSearchResultsInner.md)
 - [WWW::OpenAPIClient::Object::SearchAllFood200ResponseSearchResultsInnerResultsInner](docs/SearchAllFood200ResponseSearchResultsInnerResultsInner.md)
 - [WWW::OpenAPIClient::Object::SearchCustomFoods200Response](docs/SearchCustomFoods200Response.md)
 - [WWW::OpenAPIClient::Object::SearchCustomFoods200ResponseCustomFoodsInner](docs/SearchCustomFoods200ResponseCustomFoodsInner.md)
 - [WWW::OpenAPIClient::Object::SearchFoodVideos200Response](docs/SearchFoodVideos200Response.md)
 - [WWW::OpenAPIClient::Object::SearchFoodVideos200ResponseVideosInner](docs/SearchFoodVideos200ResponseVideosInner.md)
 - [WWW::OpenAPIClient::Object::SearchGroceryProducts200Response](docs/SearchGroceryProducts200Response.md)
 - [WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200Response](docs/SearchGroceryProductsByUPC200Response.md)
 - [WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200ResponseIngredientsInner](docs/SearchGroceryProductsByUPC200ResponseIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200ResponseNutrition](docs/SearchGroceryProductsByUPC200ResponseNutrition.md)
 - [WWW::OpenAPIClient::Object::SearchGroceryProductsByUPC200ResponseServings](docs/SearchGroceryProductsByUPC200ResponseServings.md)
 - [WWW::OpenAPIClient::Object::SearchMenuItems200Response](docs/SearchMenuItems200Response.md)
 - [WWW::OpenAPIClient::Object::SearchMenuItems200ResponseMenuItemsInner](docs/SearchMenuItems200ResponseMenuItemsInner.md)
 - [WWW::OpenAPIClient::Object::SearchRecipes200Response](docs/SearchRecipes200Response.md)
 - [WWW::OpenAPIClient::Object::SearchRecipes200ResponseResultsInner](docs/SearchRecipes200ResponseResultsInner.md)
 - [WWW::OpenAPIClient::Object::SearchRecipesByIngredients200ResponseInner](docs/SearchRecipesByIngredients200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::SearchRecipesByIngredients200ResponseInnerMissedIngredientsInner](docs/SearchRecipesByIngredients200ResponseInnerMissedIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::SearchRecipesByNutrients200ResponseInner](docs/SearchRecipesByNutrients200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurants200Response](docs/SearchRestaurants200Response.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInner](docs/SearchRestaurants200ResponseRestaurantsInner.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInnerAddress](docs/SearchRestaurants200ResponseRestaurantsInnerAddress.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInnerLocalHours](docs/SearchRestaurants200ResponseRestaurantsInnerLocalHours.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational](docs/SearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational.md)
 - [WWW::OpenAPIClient::Object::SearchSiteContent200Response](docs/SearchSiteContent200Response.md)
 - [WWW::OpenAPIClient::Object::SearchSiteContent200ResponseArticlesInner](docs/SearchSiteContent200ResponseArticlesInner.md)
 - [WWW::OpenAPIClient::Object::SearchSiteContent200ResponseGroceryProductsInner](docs/SearchSiteContent200ResponseGroceryProductsInner.md)
 - [WWW::OpenAPIClient::Object::SearchSiteContent200ResponseGroceryProductsInnerDataPointsInner](docs/SearchSiteContent200ResponseGroceryProductsInnerDataPointsInner.md)
 - [WWW::OpenAPIClient::Object::SummarizeRecipe200Response](docs/SummarizeRecipe200Response.md)
 - [WWW::OpenAPIClient::Object::TalkToChatbot200Response](docs/TalkToChatbot200Response.md)


# DOCUMENTATION FOR AUTHORIZATION

Authentication schemes defined for the API:
## apiKeyScheme

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

